summaryrefslogtreecommitdiff
path: root/sys/dev/ramdisk.h
diff options
context:
space:
mode:
authorleo <leo@NetBSD.org>1996-03-07 10:25:28 +0000
committerleo <leo@NetBSD.org>1996-03-07 10:25:28 +0000
commit6da2ce259cdee088aad1c90d3d1811fd234f191a (patch)
treea826b6f7e9468d73c1b6c01ff5b840a2590c149f /sys/dev/ramdisk.h
parent5dcce59678ce2ff58675b66710447dcb1bb84c48 (diff)
Allow for a machine dependent match function - rd_match_hook()
Diffstat (limited to 'sys/dev/ramdisk.h')
-rw-r--r--sys/dev/ramdisk.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/sys/dev/ramdisk.h b/sys/dev/ramdisk.h
index 551f65886a3..4212af83eaa 100644
--- a/sys/dev/ramdisk.h
+++ b/sys/dev/ramdisk.h
@@ -1,4 +1,4 @@
-/* $NetBSD: ramdisk.h,v 1.2 1995/10/26 15:46:24 gwr Exp $ */
+/* $NetBSD: ramdisk.h,v 1.3 1996/03/07 10:26:31 leo Exp $ */
/*
* Copyright (c) 1995 Gordon W. Ross
@@ -83,8 +83,9 @@ struct rd_conf {
/*
* If the option RAMDISK_HOOKS is on, then these functions are
* called by the ramdisk driver to allow machine-dependent to
* configure and/or load each ramdisk unit.
*/
+extern int rd_match_hook __P((struct device *, void *, void *));
extern void rd_attach_hook __P((int unit, struct rd_conf *));
extern void rd_open_hook __P((int unit, struct rd_conf *));
#endif
@@ -83,8 +83,9 @@ struct rd_conf {
* If the option RAMDISK_HOOKS is on, then these functions are
* called by the ramdisk driver to allow machine-dependent to
- * configure and/or load each ramdisk unit.
+ * match/configure and/or load each ramdisk unit.
*/